@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-07-02'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -718,9 +718,16 @@ _
             "",
             $shebang_line, "\n",
 
-            ("# code_after_shebang\n\n", $args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
+            ($args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
 
-            "# PERICMD_INLINE_SCRIPT: ", dmp(\%args), "\n\n",
+            "# PERICMD_INLINE_SCRIPT: ", do {
+                my %tmp = %args;
+                # don't show the potentially long argument values
+                for (grep {/^code_/} keys %tmp) {
+                    $tmp{$_} = "...";
+                }
+                dmp(\%tmp);
+            }, "\n\n",
 
             "# This script is generated by ", __PACKAGE__,
             " version ", (${__PACKAGE__."::VERSION"} // 'dev'), " on ",
@@ -730,6 +737,7 @@ _
             # for dzil
             "# DATE\n",
             "# VERSION\n",
+            "# PODNAME: ", ($args{program_name} // ''), "\n",
             "\n",
 
             $dp_code1,
@@ -751,7 +759,7 @@ _
                 sort keys %{$cd->{subs}}),
             "\n",
 
-            ("# code_before_parse_cmdline_options\n\n", $args{code_before_parse_cmdline_options}, "\n") x !!$args{code_before_parse_cmdline_options},
+            ($args{code_before_parse_cmdline_options}, "\n") x !!$args{code_before_parse_cmdline_options},
 
             @l,
 
@@ -807,7 +815,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.12 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-02.
+This document describes version 0.13 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-02.
 
 =head1 SYNOPSIS
 
@@ -833,23 +841,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate run 1 (lite) run --version (lite)  -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.673+-0.021/s           --               -61.2%     -79.8%         -89.1%                 -91.3%      -91.3% -97.2%
- run --version (lite)   35.274+-0.042/s 157.99+-0.5%                   --     -47.9%         -71.8%                 -77.6%      -77.7% -92.9%
- -c (lite)                  67.8+-1.3/s  395.6+-9.3%           92.1+-3.6%         --         -45.8%                 -56.9%      -57.1% -86.3%
- run 1 (inline)           125.08+-0.3/s  814.8+-2.6%        254.59+-0.96% 84.6+-3.5%             --                 -20.4%      -20.8% -74.7%
- run --version (inline)  157.17+-0.34/s   1049.5+-3%          345.6+-1.1%  132+-4.4%   25.65+-0.41%                     --       -0.4% -68.2%
- -c (inline)               157.9+-2.7/s    1055+-20%          347.5+-7.7%  133+-5.9%     26.2+-2.2%              0.4+-1.7%          -- -68.1%
- perl                        494.7+-2/s    3518+-15%         1302.5+-5.8%   630+-14%    295.5+-1.8%            214.8+-1.4% 213.4+-5.5%     --
+                                  Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.461+-0.03/s            --               -61.7%       -82.8%         -88.4%                 -91.7%      -92.4% -97.4%
+ run --version (lite)     35.18+-0.1/s 161.31+-0.95%                   --       -55.0%         -69.8%                 -78.3%      -80.2% -93.2%
+ -c (lite)               78.13+-0.21/s     480.4+-2%        122.11+-0.87%           --         -32.9%                 -51.9%      -56.1% -85.0%
+ run 1 (inline)         116.47+-0.89/s   765.2+-6.9%          231.1+-2.7%   49.1+-1.2%             --                 -28.3%      -34.6% -77.6%
+ run --version (inline) 162.43+-0.47/s  1106.7+-4.4%          361.8+-1.9% 107.9+-0.82%     39.5+-1.1%                     --       -8.8% -68.7%
+ -c (inline)              178.1+-1.3/s  1222.7+-9.9%          406.2+-3.9%  127.9+-1.7%     52.9+-1.6%            9.62+-0.84%          -- -65.7%
+ perl                     519.3+-7.2/s     3758+-54%            1376+-21%  564.7+-9.4%      345.9+-7%            219.7+-4.5% 191.7+-4.5%     --
  
  Average times:
-   perl                  :     2.0214ms
-   -c (inline)           :     6.3331ms
-   run --version (inline):     6.3625ms
-   run 1 (inline)        :     7.9949ms
-   -c (lite)             :    14.7493ms
-   run --version (lite)  :    28.3495ms
-   run 1 (lite)          :    73.1368ms
+   perl                  :     1.9257ms
+   -c (inline)           :     5.6148ms
+   run --version (inline):     6.1565ms
+   run 1 (inline)        :     8.5859ms
+   -c (lite)             :    12.7992ms
+   run --version (lite)  :    28.4252ms
+   run 1 (lite)          :    74.2887ms
 
 =head1 FUNCTIONS
 
